==> pandoc-3.7.0.2.tar.gz: pandoc-3.7.0.2/test/command/pandoc-citeproc-70.md <==
```
% pandoc --citeproc -t markdown-citations
---
references:
- ISBN: 9782503531465
  author:
  - family: 'Dinkova-Bruun'
    given: Greti
  call-number: CB351 .F564 2009
  collection-number: 50
  collection-title: Textes et études du moyen âge
  container-title: 'Florilegium mediaevale: Études offertes à Jacqueline
    Hamesse à l''occasion de son éméritat'
  editor:
  - family: Meirinhos
    given: José Francisco
  - family: Weijers
    given: Olga
  event-place: 'Louvain-la-Neuve'
  first-reference-note-number: 1
  id: 'bruun:2009samuel'
  issued:
    date-parts:
    - - 2009
  language: fr
  page: '155--174'
  publisher: 'Fédération Internationale des Instituts d''Études
    Médiévales'
  publisher-place: 'Louvain-la-Neuve'
  source: Library of Congress ISBN
  title: 'Samuel Presbyter and the Glosses to His Versification of Psalm
    1: An Anti-Church Invective?'
  title-short: Samuel Presbyter
  type: chapter
- ISSN: '0362-1529'
  author:
  - family: Thorndike
    given: Lynn
  container-title: Traditio
  first-reference-note-number: 1
  id: 'thorndike:1955unde'
  issued:
    date-parts:
    - - 1955
  language: la
  note: 'ArticleType: research-article / Full publication date: 1955 /
    Copyright © 1955 Fordham University'
  page: '163--193'
  source: JSTOR
  title: Unde versus
  type: 'article-journal'
  volume: 11
---

[@thorndike:1955unde; @bruun:2009samuel]
^D
(Thorndike 1955; Dinkova-Bruun 2009)

::::: {#refs .references .csl-bib-body .hanging-indent entry-spacing="0"}
::: {#ref-bruun:2009samuel .csl-entry}
Dinkova-Bruun, Greti. 2009. "Samuel Presbyter and the Glosses to His
Versification of Psalm 1: An Anti-Church Invective?" In *Florilegium
mediaevale: Études offertes à Jacqueline Hamesse à l'occasion de son
éméritat*, edited by José Francisco Meirinhos and Olga Weijers, 155--74.
Textes et études du moyen âge 50. Louvain-la-Neuve: Fédération
Internationale des Instituts d'Études Médiévales.
:::

::: {#ref-thorndike:1955unde .csl-entry}
Thorndike, Lynn. 1955. "Unde versus." *Traditio* 11: 163--93.
:::
:::::
```

==> pandoc-3.8.tar.gz: pandoc-3.8/test/command/pandoc-citeproc-70.md <==
```
% pandoc --citeproc -t markdown-citations
---
references:
- ISBN: 9782503531465
  author:
  - family: 'Dinkova-Bruun'
    given: Greti
  call-number: CB351 .F564 2009
  collection-number: 50
  collection-title: Textes et études du moyen âge
  container-title: 'Florilegium mediaevale: Études offertes à Jacqueline
    Hamesse à l''occasion de son éméritat'
  editor:
  - family: Meirinhos
    given: José Francisco
  - family: Weijers
    given: Olga
  event-place: 'Louvain-la-Neuve'
  first-reference-note-number: 1
  id: 'bruun:2009samuel'
  issued:
    date-parts:
    - - 2009
  language: fr
  page: '155--174'
  publisher: 'Fédération Internationale des Instituts d''Études
    Médiévales'
  publisher-place: 'Louvain-la-Neuve'
  source: Library of Congress ISBN
  title: 'Samuel Presbyter and the Glosses to His Versification of Psalm
    1: An Anti-Church Invective?'
  title-short: Samuel Presbyter
  type: chapter
- ISSN: '0362-1529'
  author:
  - family: Thorndike
    given: Lynn
  container-title: Traditio
  first-reference-note-number: 1
  id: 'thorndike:1955unde'
  issued:
    date-parts:
    - - 1955
  language: la
  note: 'ArticleType: research-article / Full publication date: 1955 /
    Copyright © 1955 Fordham University'
  page: '163--193'
  source: JSTOR
  title: Unde versus
  type: 'article-journal'
  volume: 11
---

[@thorndike:1955unde; @bruun:2009samuel]
^D
(Thorndike 1955; Dinkova-Bruun 2009)

::::: {#refs .references .csl-bib-body .hanging-indent}
::: {#ref-bruun:2009samuel .csl-entry}
Dinkova-Bruun, Greti. 2009. "Samuel Presbyter and the Glosses to His
Versification of Psalm 1: An Anti-Church Invective?" In *Florilegium
mediaevale: Études offertes à Jacqueline Hamesse à l'occasion de son
éméritat*, edited by José Francisco Meirinhos and Olga Weijers. Textes
et études du moyen âge 50. Fédération Internationale des Instituts
d'Études Médiévales.
:::

::: {#ref-thorndike:1955unde .csl-entry}
Thorndike, Lynn. 1955. "Unde versus." *Traditio* 11: 163--93.
:::
:::::
```
